.. Copyright (C) 2019, Nokia

.. image:: https://travis-ci.org/nokia/crl-remotescript.svg?branch=master
    :target: https://travis-ci.org/nokia/crl-remotescript

README
======

``crl.remotescript`` is a library for executing shell commands and scripts over SSH
and Telnet and transferring files over SFTP, SCP and FTP protocols.

Main interface is ``crl.remotescript.RemoteScript``, while multi-node specific
extensions are implemented in ``crl.remotescript.FP``.

Documentation
-------------

Documentation for ``crl.remotescript`` can be found from `Read The Docs`_.

.. _Read The Docs: http://crl-remotescript.readthedocs.io/

Installation
------------

``crl.remotescript`` library can be installed with pip::

        pip install crl.remotescript

Contributing
------------

Please see contributing_ for development and contribution practices.

The code_ and the issues_ are hosted on GitHub.

The project is licensed under BSD-3-Clause_.

.. _contributing: https://github.com/nokia/crl-remotescript/blob/master/CONTRIBUTING.rst
.. _code: https://github.com/nokia/crl-remotescript
.. _issues: https://github.com/nokia/crl-remotescript/issues
.. _BSD-3-Clause:  https://github.com/nokia/crl-remotescript/blob/master/LICENSE
